@@ -2,11 +2,12 @@
 # SPDX-License-Identifier: MPL-2.0
 
 """Defines a subclass of [`pydantic.HttpUrl`][] for use in Tidegear cogs which take advantage of Pydantic.
-Tidegear also depends on [furl](https://github.com/gruns/furl). If your cog doesn't need Pydantic, consider using that instead.
+Tidegear also depends on [yarl](https://github.com/aio-libs/yarl). If your cog doesn't need Pydantic, consider using that instead.
 """
 
 from typing import Self
 
+import yarl
 from discord.utils import MISSING
 from pydantic import HttpUrl as PydanticHttpUrl
 
@@ -53,6 +54,15 @@ class HttpUrl(PydanticHttpUrl):
         """
         return self.__truediv__(segment)
 
+    @property
+    def yarl(self) -> yarl.URL:
+        """Create a [`yarl.URL`][] object from an HttpUrl instance.
+
+        Returns:
+            The created URL object.
+        """
+        return yarl.URL(str(self))
+
     @property
     def base(self) -> "HttpUrl":
         """Wrapper around [`HttpUrl.join`][tidegear.pydantic.HttpUrl.join] that returns the base URL (scheme, host, etc.).
