@@ -14,6 +14,7 @@ from class_registry.registry import ClassRegistry
 from discord import Member, Permissions, Role, User
 from discord.utils import MISSING
 from redbot.core import commands
+from redbot.core.bot import Red
 from typing_extensions import override
 
 from tidegear import chat_formatting as cf
@@ -26,6 +27,10 @@ if TYPE_CHECKING:
     from tidegear.sentinel.db.tables import Moderation
 
 
+def _str(value: Any, bot: Red) -> str:
+    return str(value)
+
+
 @dataclass
 class ModerationMetadataEntry:
     """Dataclass representing a metadata entry within a moderation type.
@@ -42,10 +47,10 @@ class ModerationMetadataEntry:
     key: str
     human_name: str
     show_in_history: bool = False
-    func: Callable[[Any], str | Awaitable[str]] = str
+    func: Callable[[Any, Red], str | Awaitable[str]] = _str
 
-    async def _call_func(self, value: Any) -> str:
-        result = self.func(value)
+    async def _call_func(self, value: Any, bot: Red) -> str:
+        result = self.func(value, bot)
         if inspect.isawaitable(result):
             return await result
         return result
@@ -65,18 +70,19 @@ class ModerationMetadataEntry:
         moderation.metadata = orjson.dumps(meta).decode("utf-8")
         return moderation
 
-    async def fetch_from_moderation(self, moderation: "Moderation") -> str | None:
+    async def fetch_from_moderation(self, moderation: "Moderation", bot: Red) -> str | None:
         """Fetch the value of a moderation's metadata key.
 
         Args:
             moderation: The moderation to fetch metadata from.
+            bot: A bot object to pass into the metadata function.
 
         Returns:
             The fetched metadata value, or `None` if the metadata key is unset on the moderation's metadata column.
         """
         meta = moderation.meta
         if (value := meta.get(self.key, None)) is not None:
-            return await self._call_func(value)
+            return await self._call_func(value, bot)
         return None
 
 
@@ -295,7 +301,7 @@ class ModerationType:
         raise ArgumentTypeError(msg)
 
     @classmethod
-    async def convert(cls, ctx: commands.GuildContext, argument: str) -> "type[ModerationType]":
+    async def convert(cls, ctx: commands.Context, argument: str) -> "type[ModerationType]":
         """A discord.py [`commands.Converter`][discord.ext.commands.Converter] for fetching moderation types.
 
         Example:
@@ -305,7 +311,7 @@ class ModerationType:
 
 
             @commands.command()
-            async def example(self, ctx: commands.GuildContext, moderation_type: ModerationType) -> None:
+            async def example(self, ctx: commands.Context, moderation_type: ModerationType) -> None:
                 await ctx.send(content=ModerationType.key)
             ```
 
@@ -321,9 +327,9 @@ class ModerationType:
         """
         try:
             return moderation_type_registry.get_class(argument)
-        except RegistryKeyError:
+        except RegistryKeyError as e:
             msg = f"Couldn't find a moderation type with the key {cf.inline(str(argument))}!"
-            raise commands.BadArgument(msg)
+            raise commands.BadArgument(msg) from e
 
     @classmethod
     async def member_target_handler(
